## Dataset Attribution
This inventory was created by Schullo & Alperson. The use of the lexicons from
the paper is believed to be *fair use* for the reasons stated in the
`FAIR_USE.md` file.

- Original Source: _Interpersonal Phenomenology as a Function of Sexual
Orientation, Sex, Sentiment, and Trait Categories in Long-Term Dyadic
Relationships_ [[Schullo & Alperson 1984](https://psycnet.apa.org/record/1985-14446-001)].